glance library

Classes

Glance
The Glance is a singleton class for handling the monitoring functionality of UI jank detection. Call GlanceWidgetBinding.ensureInitialized before using Glance.
GlanceConfiguration
Configuration class for Glance
GlanceReporter<T>
Defines a reporter that can report specific information in Glance.
GlanceWidgetBinding
A custom binding that connects WidgetsFlutterBinding and Glance to detect UI jank during the rendering phase and from "external sources" such as callbacks from WidgetsBindingObserver, touch events, and channel messages from the platform.
JankDetectedReporter
A reporter specifically for reporting UI jank infomations.
JankReport
A report containing information about detected jank. Currently, it only includes the stack trace when UI jank occurs.

Constants

kAndroidDefaultModulePathFilters → const List<String>
Default filters for filtering module paths for Android. This filter only includes libflutter.so and libapp.so by default.
kIOSDefaultModulePathFilters → const List<String>
Default filters for filtering module paths for iOS. This filter only includes App.framework and Flutter.framework by default.